/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.planner.rest.internal.resource.v1_0;

import com.liferay.batch.planner.model.BatchPlannerLog;
import com.liferay.batch.planner.rest.dto.v1_0.Log;
import com.liferay.batch.planner.rest.resource.v1_0.LogResource;
import com.liferay.batch.planner.service.BatchPlannerLogService;
import com.liferay.portal.vulcan.pagination.Page;
import com.liferay.portal.vulcan.pagination.Pagination;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ServiceScope;

/**
 * @author Matija Petanjek
 */
@Component(
	properties = "OSGI-INF/liferay/rest/v1_0/log.properties",
	scope = ServiceScope.PROTOTYPE, service = LogResource.class
)
public class LogResourceImpl extends BaseLogResourceImpl {

	public Page<Log> getPlanLogsPage(Long id, Pagination pagination)
		throws Exception {

		return Page.of(
			transform(
				_batchPlannerLogService.getBatchPlannerLogs(
					id, pagination.getStartPosition(),
					pagination.getEndPosition()),
				this::_toLog),
			pagination, _batchPlannerLogService.getBatchPlannerLogsCount(id));
	}

	private Log _toLog(BatchPlannerLog batchPlannerLog) {
		return new Log() {
			{
				dispatchTriggerExternalReferenceCode =
					batchPlannerLog.getDispatchTriggerERC();
				exportTaskExternalReferenceCode =
					batchPlannerLog.getBatchEngineExportTaskERC();
				id = batchPlannerLog.getBatchPlannerLogId();
				importTaskExternalReferenceCode =
					batchPlannerLog.getBatchEngineImportTaskERC();
				planId = batchPlannerLog.getBatchPlannerPlanId();
				size = batchPlannerLog.getSize();
				status = batchPlannerLog.getStatus();
				total = batchPlannerLog.getTotal();
			}
		};
	}

	@Reference
	private BatchPlannerLogService _batchPlannerLogService;

}